# DatasetUpdateSettingsRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**title** | **str** | Title of the dataset | [optional] 
**subtitle** | **str** | Subtitle of the dataset | [optional] 
**description** | **str** | Decription of the dataset | [optional] 
**is_private** | **bool** | Whether or not the dataset should be private | [optional] 
**licenses** | **list[object]** | A list of licenses that apply to this dataset | [optional] 
**keywords** | **list[str]** | A list of keywords that apply to this dataset | [optional] 
**collaborators** | **list[object]** | A list of collaborators that may read or edit this dataset | [optional] 
**data** | **list[object]** | A list containing metadata for each file in the dataset | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


